#install.packages("readxl")

library("readxl")
library("yarrr")
library("lme4")
#setwd("/Users/benambridge/Desktop/Ben Work/LuCiD/Questions/Study 3")
Data=read_excel("ComplexQsResults 15.8.18.xlsx", sheet=4)
Data=as.data.frame(Data)

#Correct typos
Data$Group=gsub("experiment", "Experiment", Data$Group)
Data$Group=gsub("control", "Control", Data$Group)


Data=subset(Data, Include=="Yes")

Control=subset(Data, Group=="Control") # Check this leaves 61 particpants in each group
length(unique(Control$ParticipantCode))
Experiment=subset(Data, Group=="Experiment")
length(unique(Experiment$ParticipantCode))

Data$TrainingNPs=Data$Bingo1+Data$Bingo2+Data$Bingo3+Data$Bingo4+Data$Bingo5 # CreateCovariates
Data$TrainingQs=Data$Q1+Data$Q2+Data$Q3+Data$Q4+Data$Q5

Data$Ob  [order (Data$ParticipantCode)] <- sequence (table (Data$ParticipantCode)) # Check each has four observations
Check=aggregate(Data$Ob, list(Data$ParticipantCode), mean)
Check #Should be 6.5 each as average of trial numbers 1,2,...12

#Did all kids correctly repeat half of all noun phrases (bingo game) on every day? YES
B1=aggregate(Data$Bingo1, list(Data$ParticipantCode), mean)
B2=aggregate(Data$Bingo2, list(Data$ParticipantCode), mean)
B3=aggregate(Data$Bingo3, list(Data$ParticipantCode), mean)
B4=aggregate(Data$Bingo4, list(Data$ParticipantCode), mean)
B5=aggregate(Data$Bingo5, list(Data$ParticipantCode), mean)
Bingo=cbind(B1, B2, B3, B4, B5)
write.csv(Bingo, "Bingo.csv")

#Did all kids correctly repeat half of all questions on every day? YES
Q1=aggregate(Data$Q1, list(Data$ParticipantCode), mean)
Q2=aggregate(Data$Q2, list(Data$ParticipantCode), mean)
Q3=aggregate(Data$Q3, list(Data$ParticipantCode), mean)
Q4=aggregate(Data$Q4, list(Data$ParticipantCode), mean)
Q5=aggregate(Data$Q5, list(Data$ParticipantCode), mean)
Qs=cbind(Q1, Q2, Q3, Q4, Q5)
write.csv(Qs, "Qs.csv")

t.test(WordStr~Group, data=Data) # Check the two groups don't differ on standardized test
aggregate(Data$WordStr, list(Data$Group), mean)
aggregate(Data$WordStr, list(Data$Group), sd)
pirateplot(formula= WordStr ~ Group, data=Data, inf.method='hdi', point.o=1)

t.test(TestPeriodDays~Group, data=Data) # Check the two groups don't differ on TestPeriodDays
aggregate(Data$TestPeriodDays, list(Data$Group), mean)
aggregate(Data$TestPeriodDays, list(Data$Group), sd)
pirateplot(formula= TestPeriodDays ~ Group, data=Data, inf.method='hdi', point.o=1)

t.test(AgeInMonths~Group, data=Data) # Check the two groups don't differ on AgeInMonths
aggregate(Data$AgeInMonths, list(Data$Group), mean)
aggregate(Data$AgeInMonths, list(Data$Group), sd)
pirateplot(formula= AgeInMonths ~ Group, data=Data, inf.method='hdi', point.o=1)

## Summary data
table(Data$Agreed_Error, Data$Group)

# Compare the two groups on Correct complex questions (strict coding)
m1=glmer(Correct_S ~ Group + AgeInMonths + TestPeriodDays + WordStr + TrainingNPs + TrainingQs + (1|ParticipantCode) + (1|TargetQuestion), family=binomial, data=Data) # (still convergence problems - take out the n.s control predictors)
m2=glmer(Correct_S ~ Group + AgeInMonths + TestPeriodDays + WordStr + TrainingNPs + (1|ParticipantCode) + (1|TargetQuestion), family=binomial, data=Data) # removed TrainingQs
m2.2=glmer(Correct_S ~ Group + AgeInMonths + TestPeriodDays + WordStr + (1|ParticipantCode) + (1|TargetQuestion), family=binomial, data=Data) # removed TrainingNPs
summary(m2.2, corr=F)
drop1(m2.2, test="Chisq")
aggregate(Data$Correct_S, list(Data$Group), mean)
aggregate(Data$Correct_S, list(Data$Group), sd)
pirateplot(formula= Correct_S ~ Group, data=Data, inf.method='hdi', point.o=1)

# Compare the two groups on Correct complex questions (lenient coding)
m3=glmer(Correct_L ~ Group + AgeInMonths + TestPeriodDays + WordStr + TrainingNPs + TrainingQs + (1|ParticipantCode) + (1|TargetQuestion), family=binomial, data=Data) # (still convergence problems - take out the n.s control predictors)
m4=glmer(Correct_L ~ Group + AgeInMonths + TestPeriodDays + WordStr + TrainingNPs + (1|ParticipantCode) + (1|TargetQuestion), family=binomial, data=Data) # removed TrainingQs
m4.2=glmer(Correct_L ~ Group + AgeInMonths + TestPeriodDays + WordStr + (1|ParticipantCode) + (1|TargetQuestion), family=binomial, data=Data) # removed TrainingNPs
summary(m4.2, corr=F)

drop1(m4.2, test="Chisq") #Convergence problems here, but ignore it since we get almost identical p values to the model output
aggregate(Data$Correct_L, list(Data$Group), mean)
aggregate(Data$Correct_L, list(Data$Group), sd)
pirateplot(formula= Correct_L ~ Group, data=Data, inf.method='hdi', point.o=1)

# What if we add presentation order (not in the prereg)
Order=subset(Data, PresentationOrder>0 | PresentationOrder<13)
m5=glmer(Correct_L ~ Group + AgeInMonths + WordStr  + PresentationOrder + (1|ParticipantCode) + (1|TargetQuestion), family=binomial, data=Order) # removed TrainingQs + TrainingNPs + TestPeriodDays
summary(m5, corr=F)
# Presentation order is a significant predictor, but doesn't affect the effect of group

### Lenient coding, younger kids only (N=66)
Younger=subset(Data, AgeInMonths<67)
m6=glmer(Correct_L ~ Group + AgeInMonths + WordStr + (1|ParticipantCode) + (1|TargetQuestion), family=binomial, data=Younger) # Had to remove most control predictors!
summary(m6, corr=FALSE) # No effect (p=0.34)

### Lenient coding, worse kids only (N=47)
Worse=subset(Data, WordStr<19.68784)
m7=glmer(Correct_L ~ Group + AgeInMonths + WordStr + (1|ParticipantCode) + (1|TargetQuestion), family=binomial, data=Worse) # Had to remove most control predictors!
summary(m7, corr=FALSE) # No effect (p=0.12)

### Lenient coding, first trial only)
Earlier=subset(Data, PresentationOrder<2) #2 participants are excluded, presumably for lack of Presentation Order info
m8=glm(Correct_L ~ Group + AgeInMonths + TestPeriodDays + WordStr + TrainingNPs + TrainingQs, data=Earlier, family=binomial)
summary(m8)
aggregate(Earlier$Correct_L, list(Earlier$Group), mean)
aggregate(Earlier$Correct_L, list(Earlier$Group), sd)
length(unique(Earlier$ParticipantCode)) #Only 120 participants- lost two

### Lenient coding, first trial only, no control predictors)
Earlier=subset(Data, PresentationOrder<2) #2 participants are excluded, presumably for lack of Presentation Order info
m9=glm(Correct_L ~ Group, data=Earlier, family=binomial)
summary(m9)
aggregate(Earlier$Correct_L, list(Earlier$Group), mean)
aggregate(Earlier$Correct_L, list(Earlier$Group), sd)
length(unique(Earlier$ParticipantCode)) #Only 120 participants- lost two

# Compare the two groups on auxiliary-doubling errors
m10=glmer(Doubling ~ Group + TrainingNPs + TrainingQs + (1|ParticipantCode) + (1|TargetQuestion), family=binomial, data=Data) # (still convergence problems - take out the n.s control predictors)
summary(m10, corr=F)
drop1(m10, test="Chisq")
aggregate(Data$Doubling, list(Data$Group), mean)

aggregate(Data$Doubling, list(Data$Group), sd)

pirateplot(formula= Correct_S ~ Group, data=Data, inf.method='hdi', point.o=1)







###### Now Chi-square tests


##Chi-square test shows almost equal performance between the two groups - First strict
Chi=aggregate(Data$Correct_S, list(Data$ParticipantCode, Data$Group), mean)
colnames(Chi)=c("Participant", "Group", "Correct")
Experiment=subset(Chi, Group=="Experiment")
ExperimentFail=subset(Experiment, Correct==0)
length(ExperimentFail$Participant) ## Experimental group is 40 success and 21 failure
Control=subset(Chi, Group=="Control")
ControlFail=subset(Control, Correct==0)
length(ControlFail$Participant) ## Control group is 35 success and 26 failure
chi=matrix(c(40,21,35,26), byrow=T, 2,2)
fisher.test(chi)
chisq.test(chi)

##Chi-square test shows almost equal performance between the two groups - Now lenient
Chi=aggregate(Data$Correct_L, list(Data$ParticipantCode, Data$Group), mean)
colnames(Chi)=c("Participant", "Group", "Correct")
Experiment=subset(Chi, Group=="Experiment")
ExperimentFail=subset(Experiment, Correct==0)
length(ExperimentFail$Participant) ## Experimental group is 41 success and 20 failure
Control=subset(Chi, Group=="Control")
ControlFail=subset(Control, Correct==0)
length(ControlFail$Participant) ## Control group is 42 success and 19 failure
chi=matrix(c(41,20,42,19), byrow=T, 2,2)
fisher.test(chi)
chisq.test(chi)

##Chi-square test shows almost equal performance between the two groups - Now lenient, but with younger kids only
Younger=subset(Data, AgeInMonths<67)
Chi=aggregate(Younger$Correct_L, list(Younger$ParticipantCode, Younger$Group), mean)
colnames(Chi)=c("Participant", "Group", "Correct")
Experiment=subset(Chi, Group=="Experiment")
ExperimentPass=subset(Experiment, Correct>0)
length(ExperimentPass$Participant) ## Experimental group is 18 passes...
ExperimentFail=subset(Experiment, Correct==0)
length(ExperimentFail$Participant) ## and 15 failures
Control=subset(Chi, Group=="Control")
ControlPass=subset(Control, Correct>0)
length(ControlPass$Participant) ## Control group is 20 passes...
ControlFail=subset(Control, Correct==0)
length(ControlFail$Participant) ## and 13 failures

##Chi-square test -  Now lenient, but first trial only
Earlier=subset(Data, PresentationOrder<2) #2 participants are excluded, presumably for lack of Presentation Order info
Chi=aggregate(Earlier$Correct_L, list(Earlier$ParticipantCode, Earlier$Group), mean)
colnames(Chi)=c("Participant", "Group", "Correct")
Experiment=subset(Chi, Group=="Experiment")
ExperimentPass=subset(Experiment, Correct>0)
length(ExperimentPass$Participant) ## Experimental group is 25 passes...
ExperimentFail=subset(Experiment, Correct==0)
length(ExperimentFail$Participant) ## and 35 failures
Control=subset(Chi, Group=="Control")
ControlPass=subset(Control, Correct>0)
length(ControlPass$Participant) ## Control group is 16 passes...
ControlFail=subset(Control, Correct==0)
length(ControlFail$Participant) ## and 44 failures
chi=matrix(c(25,35,16,44), byrow=T, 2,2)
fisher.test(chi)
chisq.test(chi)
25/60
16/60

#### At least on the basis of the chi-square analysis, there's
#### no point in doing the same thing again with only the younger age. And sticking with this younger age and
#### changing to "that" would probably see even more successes. The only options are to go younger than Reception
#### (seems tricky since this is a hard task), or to screen out kids who can't do it (again, tricky, because you'd
#### be screening in lots of kids who have poor language, so will struggle at the task).











library(brms)

### Fit a simlar Bayesian model
fit1 <- brm(formula = Correct_L ~ (1|ParticipantCode) + (1|TargetQuestion) 
            + Group + AgeInMonths + TestPeriodDays + WordStr + TrainingNPs + TrainingQs, data=Data, 
            family = bernoulli(), 
            set_prior("normal(0,2)", class = "b"), cores=4,
            warmup = 2000, iter = 5000, chains = 4)

### Fit a maximal Bayesian model
fit2 <- brm(formula = Correct_L ~ (1|ParticipantCode) + (1+Group + AgeInMonths + TestPeriodDays + WordStr + TrainingNPs + TrainingQs|TargetQuestion) 
            + Group + AgeInMonths + TestPeriodDays + WordStr + TrainingNPs + TrainingQs, data=Data, 
            family = bernoulli(), 
            set_prior("normal(0,2)", class = "b"), cores=4,
            warmup = 2000, iter = 5000, chains = 4)


### Summarize the model
summary(fit2, WAIC=T)


### Calculate pMCMC values ("Bayesian p values")
samps = as.matrix(as.mcmc(fit2))
C1=mean(samps[,1] > 0)
C2=mean(samps[,2] < 0)
C3=mean(samps[,3] < 0)
C4=mean(samps[,4] > 0)
C5=mean(samps[,5] < 0)
C6=mean(samps[,6] > 0)
C7=mean(samps[,7] > 0)
pMCMC=as.data.frame(c(C1,C2,C3,C4,C5,C6,C7))
names=as.data.frame(parnames(fit1)[1:7])
Table=cbind(names, pMCMC)
colnames(Table)=c("Population-Level (fixed) Effect", "pMCMC")
Table






